California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 003 - ACA 5 (RESOLUTION CHAPTER 125, STATUTES OF 2023) LOW. MARRIAGE EQUALITY. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1297793 | DE LEON BELIEVING IN A BETTER CALIFORNIA BALLOT MEASURE COMMITTEE - YES ON PROPOSITIONS 3, 32 AND 33; KEVIN | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1340742 | YES ON PROPOSITION 3, SPONSORED BY EQUALITY CALIFORNIA | SUPPORT